pub struct DetachedArgs {
pub output: Option<OutputFormat>,
pub idle_after: Option<u64>,
pub on_idle: Option<String>,
}Fields
output: Option<OutputFormat>Output format for when no clients are attached.
idle_after: Option<u64>How many seconds to wait after the agent becomes idle before running the –on-idle command.
on_idle: Option<String>Shell command to spawn when the agent becomes idle.