pub struct ServerArgs {
pub listen: SocketAddr,
pub cwd: PathBuf,
pub prompt: Option<String>,
pub output: OutputFormat,
pub idle_after: Option<u64>,
pub on_idle: Option<String>,
pub acp: AcpArgs,
}Fields
listen: SocketAddrAddress to listen on. The raw server is unauthenticated; use a private network or authenticating proxy.
cwd: PathBufServer workspace used to resolve settings and as the default session directory.
prompt: Option<String>Initial prompt to run.
output: OutputFormatFormat for agent events written to stdout/stderr.
idle_after: Option<u64>How many seconds to wait after the agent becomes idle before running the –on-idle command.
on_idle: Option<String>Shell command to spawn when the agent becomes idle.
acp: AcpArgsTrait Implementations
Sourceimpl Args for ServerArgs
impl Args for ServerArgs
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl Debug for ServerArgs
impl Debug for ServerArgs
Sourceimpl FromArgMatches for ServerArgs
impl FromArgMatches for ServerArgs
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Auto Trait Implementations
impl Freeze for ServerArgs
impl RefUnwindSafe for ServerArgs
impl Send for ServerArgs
impl Sync for ServerArgs
impl Unpin for ServerArgs
impl UnsafeUnpin for ServerArgs
impl UnwindSafe for ServerArgs