pub struct AcpOptions {
pub log_dir: Option<PathBuf>,
pub providers: Option<BTreeMap<String, ProviderConnectionOverride>>,
pub settings: Option<AetherSettings>,
pub settings_file: Option<PathBuf>,
pub agent: Option<String>,
pub model: Option<String>,
pub reasoning_effort: Option<ReasoningEffort>,
}Fields
log_dir: Option<PathBuf>providers: Option<BTreeMap<String, ProviderConnectionOverride>>settings: Option<AetherSettings>settings_file: Option<PathBuf>agent: Option<String>model: Option<String>reasoning_effort: Option<ReasoningEffort>Trait Implementations
Sourceimpl Clone for AcpOptions
impl Clone for AcpOptions
Sourcefn clone(&self) -> AcpOptions
fn clone(&self) -> AcpOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AcpOptions
impl Debug for AcpOptions
Sourceimpl Default for AcpOptions
impl Default for AcpOptions
Sourcefn default() -> AcpOptions
fn default() -> AcpOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AcpOptions
impl<'de> Deserialize<'de> for AcpOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AcpOptions
impl JsonSchema for AcpOptions
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AcpOptions
impl RefUnwindSafe for AcpOptions
impl Send for AcpOptions
impl Sync for AcpOptions
impl Unpin for AcpOptions
impl UnsafeUnpin for AcpOptions
impl UnwindSafe for AcpOptions