pub struct EvalArgs {
pub paths: Vec<PathBuf>,
pub name: Option<String>,
pub max_concurrency: NonZeroUsize,
pub output: OutputFormat,
pub spec_file: Option<String>,
pub retain_workspace: bool,
pub base_dir: Option<PathBuf>,
}Fields
paths: Vec<PathBuf>Eval JSON files or directories to discover eval files under. Defaults to ./evals.
name: Option<String>Run only the eval with this name.
max_concurrency: NonZeroUsizeMaximum number of eval files to run concurrently.
output: OutputFormatOutput format
spec_file: Option<String>Run a single eval from a JSON file, or from stdin with -. Emits newline-delimited
EvalStreamEvent JSON on stdout: an agent_message event per agent message as it streams,
terminated by one outcome event.
retain_workspace: boolRetain the eval workspace on disk and include retainedWorkspace in JSON output. Used with
--spec-file.
base_dir: Option<PathBuf>Base directory for resolving relative paths in a --spec-file spec. Defaults to the current
working directory.