pub struct HeadlessOptions {
pub prompt: Option<String>,
pub cwd: Option<PathBuf>,
pub providers: Option<BTreeMap<String, ProviderConnectionOverride>>,
pub settings: Option<AetherSettings>,
pub settings_file: Option<PathBuf>,
pub agent: Option<String>,
pub model: Option<String>,
pub mcp_config: Option<McpConfig>,
pub system_prompt: Option<String>,
pub output: Option<OutputFormat>,
pub verbose: Option<bool>,
pub events: Option<Vec<CliEventKind>>,
}Fields
prompt: Option<String>cwd: Option<PathBuf>providers: Option<BTreeMap<String, ProviderConnectionOverride>>settings: Option<AetherSettings>settings_file: Option<PathBuf>agent: Option<String>model: Option<String>mcp_config: Option<McpConfig>system_prompt: Option<String>output: Option<OutputFormat>verbose: Option<bool>events: Option<Vec<CliEventKind>>Trait Implementations
Sourceimpl Clone for HeadlessOptions
impl Clone for HeadlessOptions
Sourcefn clone(&self) -> HeadlessOptions
fn clone(&self) -> HeadlessOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HeadlessOptions
impl Debug for HeadlessOptions
Sourceimpl Default for HeadlessOptions
impl Default for HeadlessOptions
Sourcefn default() -> HeadlessOptions
fn default() -> HeadlessOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for HeadlessOptions
impl<'de> Deserialize<'de> for HeadlessOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HeadlessOptions
impl JsonSchema for HeadlessOptions
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HeadlessOptions
impl RefUnwindSafe for HeadlessOptions
impl Send for HeadlessOptions
impl Sync for HeadlessOptions
impl Unpin for HeadlessOptions
impl UnsafeUnpin for HeadlessOptions
impl UnwindSafe for HeadlessOptions