pub struct FakeAcpAgent { /* private fields */ }Implementations
Sourceimpl FakeAcpAgent
impl FakeAcpAgent
pub fn name(&self) -> &str
Sourcepub fn assert_saw(&self, expected: &[&str])
pub fn assert_saw(&self, expected: &[&str])
Asserts the agent’s most recent turn saw a conversation containing each
of expected (user or assistant text), in addition to anything else.
Sourcepub fn assert_saw_exactly(&self, expected: &[&str])
pub fn assert_saw_exactly(&self, expected: &[&str])
Asserts the agent’s most recent turn saw exactly expected and nothing
else — used to prove a freshly-activated agent started with no prior
transcript.
Sourcepub fn assert_never_ran(&self)
pub fn assert_never_ran(&self)
Asserts the agent never ran a turn (its LLM was never invoked).