RuntimeBuilder

Struct RuntimeBuilder 

pub struct RuntimeBuilder { /* private fields */ }

Implementations

Source

impl RuntimeBuilder

pub fn new(cwd: &Path, model: &str) -> Result<Self, CliError>

pub fn from_spec(cwd: PathBuf, spec: AgentSpec) -> Self

pub fn prompt_cache_key(self, key: String) -> Self

pub fn mcp_sources(self, sources: Vec<McpConfigSource>) -> Self

Set MCP config source overrides. When non-empty, these completely replace any sources resolved from the agent’s AgentSpec.

pub fn extra_servers(self, servers: Vec<McpServer>) -> Self

pub fn oauth_handler_factory(self, factory: OAuthHandlerFactory) -> Self

pub fn oauth_credential_store( self, store: Arc<dyn OAuthCredentialStorage>, ) -> Self

pub async fn build( self, custom_prompt: Option<Prompt>, messages: Option<Vec<ChatMessage>>, ) -> Result<Runtime, CliError>

pub async fn build_ready( self, messages: Vec<ChatMessage>, ) -> Result<(Runtime, McpConnectionDetails), CliError>

Spawn MCP, block until every server finishes its initial connection, then build an agent pre-seeded with the connection’s filtered tools and MCP instructions. Returns the live Runtime plus the bootstrap snapshot. Unlike build (which starts with no tools and relies on the MCP event stream to populate them later), this is for callers that need the agent ready to use tools on its first turn.

pub async fn build_prompt_info(self) -> Result<PromptInfo, CliError>